function Q = qr_orth(A)
%QR_ORTH   Orthogonalization based on QR-factorization.
%   Q = QR_ORTH(A) is an orthonormal basis for the range of A.
%   That is, Q'*Q = I, the columns of Q span the same space as 
%   the columns of A, and the number of columns of Q is an approximation of 
%   the (numerical) rank of A.
%   Modified version of the MATLAB built-in ORTH: Oct 2017 Emil Ringh


[QQ,R] = qr(A,0);
Q = [];

if ~isempty(R)
    r = diag(R);
    tol = max(size(A)) * eps(class(A));
    for i = 1:length(r)
      if abs(r(i)) > tol
        Q = [Q, QQ(:,i)];
      end
    end
end
